@@ -169,7 +169,12 @@ public class ParseCamt05200103 extends AbstractCamtParser
         
         // ditto
         EntryTransaction3 tx = txList.get(0);
-        
+
+        // Ist es eine Rueckbuchung?
+        boolean rueckbuchung = tx.getRtrInf() != null && tx.getRtrInf().getRsn() != null && tx.getRtrInf().getRsn().getCd() != null && tx.getRtrInf().getRsn().getCd().length() > 0;
+        if (rueckbuchung) // Bei Rueckbuchung tauschen wir Creditor und Debitor
+          haben = !haben;
+
         ////////////////////////////////////////////////////////////////////////
         // Buchungs-ID
         TransactionReferences3 ref = tx.getRefs();
